;; Generated package description from xref.el  -*- no-byte-compile: t -*-
(define-package "xref" "1.4.1.0.20220620.4414" "Cross-referencing commands" '((emacs "26.1")) :commit "1172c7303dbce015d12424739a56bfce00e195b1" :url "https://elpa.gnu.org/packages/xref.html")
